//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;

using SolidBrush = MindFusion.Drawing.SolidBrush;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Ternary
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void MainForm_Load(object sender, EventArgs e)
		{
			diagram.DefaultShape = Shapes.Ellipse;
            diagram.ShapeNodeStyle.Brush = new MindFusion.Drawing.LinearGradientBrush(Color.FromArgb(224, 233, 233),
                Color.FromArgb(90, 121, 165));
            diagram.DiagramLinkStyle.Stroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(45, 57, 86));
            diagram.BackBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(224, 233, 233));

			ShapeNode b1 = diagram.Factory.CreateShapeNode(10, 10, 35, 15);
			ShapeNode b2 = diagram.Factory.CreateShapeNode(100, 10, 35, 15);

			diagram.Factory.CreateDiagramLink(b1, b2);

			ShapeNode b3 = diagram.Factory.CreateShapeNode(50, 70, 35, 15);
			b3.PolygonalTextLayout = true;
			b3.Text = "Draw a new link from here to the link above.";
		}

		private void diagramView_MouseMove(object sender, MouseEventArgs e)
		{
			if (e.Button == MouseButtons.Left)
			{
				Point clientPt = new Point(e.X, e.Y);
				PointF docPt = diagramView.ClientToDoc(clientPt);
				DiagramLink arrow = diagram.GetLinkAt(docPt, 1, true);
				if (arrow == null)
					diagramView.AllowLinkCursor = Cursors.No;
				else
					diagramView.AllowLinkCursor = Cursors.Hand;
			}
		}

		private void diagram_LinkCreated(object sender, LinkEventArgs e)
		{
			DiagramLink a = e.Link;

			// if not connected to a real node
			if (a.Destination is DummyNode)
			{
				PointF endPt = a.ControlPoints[a.ControlPoints.Count - 1];
				a.Locked = true; // so we can exclude it from the search
				DiagramLink trg = diagram.GetLinkAt(endPt, 1, true);
				if (trg != null)
				{
					DiagramNode n1 = trg.Origin;
					DiagramNode n2 = trg.Destination;
					DiagramNode n3 = a.Origin;

					ShapeNode connector = diagram.Factory.CreateShapeNode(
						endPt.X - 2.5f, endPt.Y - 2.5f, 5, 5);
					connector.Shape = Shapes.Decision;
                    connector.Brush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(156, 170, 198));

					diagram.Factory.CreateDiagramLink(connector, n1);
					diagram.Factory.CreateDiagramLink(connector, n2);
					diagram.Factory.CreateDiagramLink(connector, n3);

					diagram.Links.Remove(trg);

					// setup the connector box
					diagram.Selection.Clear();
					connector.Selected = true;
					connector.HandlesStyle = HandlesStyle.MoveOnly;
                    //connector.Brush = new SolidBrush(Color.Khaki);
				}

				diagram.Links.Remove(a);
			}
		}
	}
}